( cd dev ; rm -rf X0R )
( cd dev ; ln -sf null X0R )
( cd dev ; rm -rf core )
( cd dev ; ln -sf /proc/kcore core )
( cd dev ; rm -rf cpcmd )
( cd dev ; ln -sf cpint8 cpcmd )
( cd dev ; rm -rf cpmon )
( cd dev ; ln -sf cpint220 cpmon )
( cd dev ; rm -rf fd )
( cd dev ; ln -sf /proc/self/fd fd )
( cd dev ; rm -rf nfsd )
( cd dev ; ln -sf socksys nfsd )
( cd dev ; rm -rf nftape )
( cd dev ; ln -sf nrft0 nftape )
( cd dev ; rm -rf nrmt0 )
( cd dev ; ln -sf nst0 nrmt0 )
( cd dev ; rm -rf nrmt1 )
( cd dev ; ln -sf nst1 nrmt1 )
( cd dev ; rm -rf ram )
( cd dev ; ln -sf ram0 ram )
( cd dev ; rm -rf rmt0 )
( cd dev ; ln -sf st0 rmt0 )
( cd dev ; rm -rf rmt1 )
( cd dev ; ln -sf st1 rmt1 )
( cd dev ; rm -rf stderr )
( cd dev ; ln -sf fd/2 stderr )
( cd dev ; rm -rf stdin )
( cd dev ; ln -sf fd/0 stdin )
( cd dev ; rm -rf stdout )
( cd dev ; ln -sf fd/1 stdout )
( cd dev ; rm -rf systty )
( cd dev ; ln -sf console systty )
# just in case
chmod 666 dev/ptmx
# end just in case
